@@ -1,3 +1,3 @@
 """DoHome Lights controlling module"""
-from .gateway import DoHomeGateway, create_gateway
+from .gateway import DoHomeGateway
 from .light import DoHomeLight, DoHomeLightsBroadcast
